Welcome to funzu | Craziest photo blog on the net
Description: funzu.com Your Daily Entertainment Dose. daily new videos and crazy funny pictures images uploaded to entertain you.
Keywords: Entertainment, fun, video, images, pictures, funny, funny image, crazy picrure, videos, Fun, Daily, daily, crazy pictures, funny pictures, funny images, crazy images, daily new fun, prank videos, new pranks, office prank, prectical prank, hidden camera, candid camera, practical fun, prectical fun, practical prank, Hidden camera fun, Candid camera fun, hidden camera prank, candid camera prank videos,

# Famous Faces Come Together With Facemath (30 Photos)

Famous Faces Come Together With Facemath (30 Photos)
30 images...

Read more... Add new comment

# Taking Windsurfing to the Next Level (13 Photos)

Taking Windsurfing to the Next Level (13 Photos)
13 images...
When windsurfing becomes icesurfing.

Read more... Add new comment

# Sculpture Made out of Books (10 Photos)

Sculpture Made out of Books (10 Photos)
10 images...
This sculptor must have considered some books really boring if he thought that this would be a better use for them.

Read more... Add new comment

# Christmas Present for a Brother (17 Photos)

Christmas Present for a Brother (17 Photos)
17 images...
A very unnusual and funny way to wrap a present for your brother or a sister))

Read more... Add new comment

# Getting an iPad for Christmas? (17 Photos)

Getting an iPad for Christmas? (17 Photos)
17 images...
She thought she was going to get an iPad for Christmas...

Read more... Add new comment

# Cat Transit System (17 Photos)

Cat Transit System (17 Photos)
17 images...
Very cool Cat Transit System (CTS) built by Jillian Northrup from Oakland, USA.

Read more... Add new comment

# Most Priceless Youtube Comments in 2012 (24 Photos)

Most Priceless Youtube Comments in 2012 (24 Photos)
24 images...

Read more... Add new comment

# Lifting the Escalator of the 101st Floor of the WTC (10 Photos)

Lifting the Escalator of the 101st Floor of the WTC (10 Photos)
10 images...

Read more... Add new comment

# Horse Rescued In Florida (7 Photos)

Horse Rescued In Florida (7 Photos)
7 images...
Andy, a 30-year old horse is seen being rescued by Florida police, after the horse jumped into a local's backyard and landed in their swimming pool.

Read more... Add new comment

# Plane for Kids (6 Photos)

Plane for Kids (6 Photos)
6 images...
There is a private kindergarten in Rustavi, where Yak-40 has established. The owner of the garden Harry Chapidze bought a decommissioned aircraft in Tbilisi. The aircraft was restored in a few months and made into a children's play room, the cockpit remained intact.

Read more... Add new comment

# Dinner Is Served (6 Photos)

Dinner Is Served (6 Photos)
6 images...
This poor insect doesn’t stand a chance against the crafty chameleon.

Read more... Add new comment

# The Alphabet and the Famous Movies (26 Photos)

The Alphabet and the Famous Movies (26 Photos)
26 images...
A selection of movie names in alphabetical order...

Read more... Add new comment

# Pumpkin-Carving Tutorial (13 Photos)

Pumpkin-Carving Tutorial (13 Photos)
13 images...
Let's get ready for Halloween.
Read more... Add new comment

# Life of a Baby Panda (9 Photos)

Life of a Baby Panda (9 Photos)
9 images...
Back in 2010 panda Cao Cao gave birth to a cub Tao Tao in China zoo. It was supposed to be released when it got older. Meanwhile, vets and caretakers dressed in panda suits when they did health checks and moved the cub. The hope was the cubs will have a natural fear of humans if they were released.

Read more... Add new comment

# Luxurious Cave House in Historic City (14 Photos)

Luxurious Cave House in Historic City (14 Photos)
14 images...
The Domus Civita is a house located on the top of the Etruscan tombs and caves in Italy. Originally built in XIV century, the owners have attempted to preserve all the natural beams, stone walls and floors while transforming this natural cave into a comfortable living space. The house has been fully restored, maintaining all historical value, and now boasts a heated pool and wine cellar.

Read more... Add new comment
1 2 3 4 5 6 7 8 9 10»End